Pandas on Dask
==============

The Dask engine and documentation could use your help! Consider opening a
`pull request`_ or an issue_ to contribute or ask clarifying questions.

.. _pull request: https://github.com/modin-project/modin/pulls
.. _issue: https://github.com/modin-project/modin/issues
